import { CreatePolicyRequest as CreatePolicyRequest$1, CreatePolicyResponse as CreatePolicyResponse$1, UpdatePolicyRequest as UpdatePolicyRequest$1, UpdatePolicyResponse as UpdatePolicyResponse$1, DeletePolicyRequest as DeletePolicyRequest$1, DeletePolicyResponse as DeletePolicyResponse$1, QueryPoliciesRequest as QueryPoliciesRequest$1, QueryPoliciesResponse as QueryPoliciesResponse$1, ReorderEventPoliciesRequest as ReorderEventPoliciesRequest$1, ReorderEventPoliciesResponse as ReorderEventPoliciesResponse$1, GetPolicyRequest as GetPolicyRequest$1, GetPolicyResponse as GetPolicyResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface Policy {
    /**
     * Policy ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Revision number, which increments by 1 each time the policy is updated.
     *
     * To prevent conflicting changes, the current revision must be used when updating a policy.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the policy was created in `yyyy-mm-ddThh:mm:sssZ` format.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the policy was updated in `yyyy-mm-ddThh:mm:sssZ` format.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Policy name that is visible in the dashboard and checkout form.
     *
     * Min: 1 character  <br/>
     * Max: 40 characters
     * @minLength 1
     * @maxLength 40
     */
    name?: string;
    /**
     * Policy body. Usually contains various terms and conditions.
     *
     * Min: 1 character
     * Max: 50,000 characters
     *
     * <b>Note:</b> You can format text using various HTML tags such as `<p>`, `<b>`, `<ul>`, etc.
     * @minLength 1
     * @maxLength 50000
     */
    body?: string;
    /**
     * ID of the event to which the policy belongs.
     * @format GUID
     * @immutable
     */
    eventId?: string;
}
interface CreatePolicyRequest {
    /** Policy info. */
    policy: Policy;
}
interface CreatePolicyResponse {
    /** Created policy. */
    policy?: Policy;
}
interface UpdatePolicyRequest {
    /** Policy info to update. */
    policy: Policy;
}
interface UpdatePolicyResponse {
    /** Updated policy. */
    policy?: Policy;
}
interface DeletePolicyRequest {
    /**
     * ID of the policy to delete.
     * @format GUID
     */
    policyId: string;
}
interface DeletePolicyResponse {
}
interface QueryPoliciesRequest {
    /** Query options. See [API Query Langauge](https://dev.wix.com/api/rest/getting-started/api-query-language) for more details. */
    query: QueryV2;
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Pagination options. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /** Filter object in the following format: <br/> `"filter" : { "fieldName1": "value1", "fieldName2":{"$operator":"value2"} }`. <br/> <br/> **Example:** <br/> `"filter" : { "id": "2224a9d1-79e6-4549-a5c5-bf7ce5aac1a5", "revision": {"$ne":"1"} }` <br/> <br/> See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/policy-v2/filter-and-sort) for more information. */
    filter?: Record<string, any> | null;
    /** Sort object in the following format: <br/> `[{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]` <br/> <br/> **Example:** <br/> `[{"fieldName":"createdDate","direction":"DESC"}]` <br/> <br/> See [supported fields](https://dev.wix.com/api/rest/wix-events/policy-v2/filter-and-sort) for more information. */
    sort?: Sorting[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Pagination options. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 100
     */
    fieldName?: string;
    /** Sort order (ASC/DESC). Defaults to ASC */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /** Number of items to load per page. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface CursorPaging {
    /**
     * Number of items to load per page.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     * You can get the relevant cursor token
     * from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
interface QueryPoliciesResponse {
    /** List of policies. */
    policies?: Policy[];
    /** Metadata for the paginated results. */
    metadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /** Cursor pointing to next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to previous page in the list of results. */
    prev?: string | null;
}
interface ReorderEventPoliciesRequest extends ReorderEventPoliciesRequestReferencePolicyOneOf {
    /**
     * Move the given policy before this specified policy.
     * @format GUID
     */
    beforePolicyId?: string;
    /**
     * Move the given policy after this specified policy.
     * @format GUID
     */
    afterPolicyId?: string;
    /**
     * Event ID to which the policy belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * ID of the policy to reorder.
     * @format GUID
     */
    policyId: string;
}
/** @oneof */
interface ReorderEventPoliciesRequestReferencePolicyOneOf {
    /**
     * Move the given policy before this specified policy.
     * @format GUID
     */
    beforePolicyId?: string;
    /**
     * Move the given policy after this specified policy.
     * @format GUID
     */
    afterPolicyId?: string;
}
interface ReorderEventPoliciesResponse {
    /** Policies in the new order. */
    policies?: Policy[];
}
interface GetPolicyRequest {
    /**
     * ID of the policy to retrieve.
     * @format GUID
     */
    policyId: string;
}
interface GetPolicyResponse {
    /** Retrieved policy. */
    policy?: Policy;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createPolicy(): __PublicMethodMetaInfo<'POST', {}, CreatePolicyRequest$1, CreatePolicyRequest, CreatePolicyResponse$1, CreatePolicyResponse>;
declare function updatePolicy(): __PublicMethodMetaInfo<'PATCH', {
    policyId: string;
}, UpdatePolicyRequest$1, UpdatePolicyRequest, UpdatePolicyResponse$1, UpdatePolicyResponse>;
declare function deletePolicy(): __PublicMethodMetaInfo<'DELETE', {
    policyId: string;
}, DeletePolicyRequest$1, DeletePolicyRequest, DeletePolicyResponse$1, DeletePolicyResponse>;
declare function queryPolicies(): __PublicMethodMetaInfo<'POST', {}, QueryPoliciesRequest$1, QueryPoliciesRequest, QueryPoliciesResponse$1, QueryPoliciesResponse>;
declare function reorderEventPolicies(): __PublicMethodMetaInfo<'POST', {}, ReorderEventPoliciesRequest$1, ReorderEventPoliciesRequest, ReorderEventPoliciesResponse$1, ReorderEventPoliciesResponse>;
declare function getPolicy(): __PublicMethodMetaInfo<'GET', {
    policyId: string;
}, GetPolicyRequest$1, GetPolicyRequest, GetPolicyResponse$1, GetPolicyResponse>;

export { type __PublicMethodMetaInfo, createPolicy, deletePolicy, getPolicy, queryPolicies, reorderEventPolicies, updatePolicy };
