import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { Policy, CreatePolicyApplicationErrors, UpdatePolicy, PoliciesQueryBuilder, ReorderEventPoliciesOptions, ReorderEventPoliciesResponse, ReorderEventPoliciesApplicationErrors, PolicyCreatedEnvelope, PolicyDeletedEnvelope, PolicyUpdatedEnvelope } from './index.typings.mjs';
export { ActionEvent, Address, AddressLocation, AddressStreetOneOf, BaseEventMetadata, CreatePolicyRequest, CreatePolicyResponse, CursorPaging, Cursors, DeletePolicyRequest, DeletePolicyResponse, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventCopied, EventMetadata, EventStatus, GetPolicyRequest, GetPolicyResponse, IdentificationData, IdentificationDataIdOneOf, Location, LocationType, MapCoordinates, MessageEnvelope, Occurrence, Paging, PagingMetadataV2, PoliciesQueryResult, QueryPoliciesRequest, QueryPoliciesResponse, QueryV2, QueryV2PagingMethodOneOf, Recurrences, ReorderEventPoliciesOptionsReferencePolicyOneOf, ReorderEventPoliciesRequest, ReorderEventPoliciesRequestReferencePolicyOneOf, RestoreInfo, ScheduleConfig, SortOrder, Sorting, Status, StreetAddress, Subdivision, SubdivisionType, UpdatePolicyRequest, UpdatePolicyResponse, UpdatePolicySortIndexRequest, UpdatePolicySortIndexResponse, WebhookIdentityType } from './index.typings.mjs';

type PolicyNonNullablePaths = `name` | `body` | `eventId`;
declare function createPolicy$1(httpClient: HttpClient): CreatePolicySignature;
interface CreatePolicySignature {
    /**
     * Creates a policy.
     *
     *
     * <!--
     * >  Note: This function is restricted and only runs if you elevate permissions using the [wix-auth.elevate()](https://www.wix.com/velo/reference/wix-auth/elevate) function.
     * -->
     *
     * The `createPolicy()` function returns a Promise that resolves to the newly-created policy.
     *
     * You can create up to 3 policies per event. If you try to create more than 3, you'll get the "Maximum number of policies for the event has been reached" error.
     * @param - Policy info.
     * @returns Created policy.
     */
    (policy: NonNullablePaths<Policy, `body` | `eventId` | `name`>): Promise<NonNullablePaths<Policy, PolicyNonNullablePaths> & {
        __applicationErrorsType?: CreatePolicyApplicationErrors;
    }>;
}
declare function updatePolicy$1(httpClient: HttpClient): UpdatePolicySignature;
interface UpdatePolicySignature {
    /**
     * Updates a policy.
     *
     * <!--
     * > Note: This function is restricted and only runs if you elevate permissions using the [wix-auth.elevate()](https://www.wix.com/velo/reference/wix-auth/elevate) function.
     * -->
     *
     * The `updatePolicy()` function returns a Promise that resolves to the newly-updated policy.
     *
     * Each time the policy is updated, `revision` increments by 1. The existing `revision` must be included when updating the policy. This ensures you're working with the latest policy and prevents unintended overwrites.
     * @param - Policy to update.
     * @param - Policy ID.
     * @returns The updated policy.
     */
    (_id: string, policy: NonNullablePaths<UpdatePolicy, `body` | `eventId` | `name` | `revision`>): Promise<NonNullablePaths<Policy, PolicyNonNullablePaths>>;
}
declare function deletePolicy$1(httpClient: HttpClient): DeletePolicySignature;
interface DeletePolicySignature {
    /**
     * Permanently deletes a policy.
     *
     *
     * <!--
     * > Note: This function is restricted and only runs if you elevate permissions using the [wix-auth.elevate()](https://www.wix.com/velo/reference/wix-auth/elevate) function.
     * -->
     *
     * The `deletePolicy()` function returns a Promise that resolves when the specified policy is deleted.
     *
     * Deleted policies are not returned by the `getPolicy()` or `queryPolicies()` functions.
     * @param - Options for Delete Policy function.
     * @param - ID of the policy to delete.
     */
    (policyId: string): Promise<void>;
}
declare function queryPolicies$1(httpClient: HttpClient): QueryPoliciesSignature;
interface QueryPoliciesSignature {
    /**
     * Creates a query to retrieve a list of policies, given the provided paging and filter.
     *
     *
     * The `queryPolicies()` function builds a query to retrieve a list of policies and returns a [PoliciesQueryBuilder](https://www.wix.com/velo/reference/wix-events-v2/policies/policiesquerybuilder) object.
     *
     * The returned object contains the query definition which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/policies/policiesquerybuilder/find) function.
     *
     * You can refine the query by chaining `PoliciesQueryBuilder` functions onto the query. `PoliciesQueryBuilder` functions enable you to sort, filter and control the results that `PoliciesQueryBuilder.find()` returns.
     *
     * The query runs with the following `PoliciesQueryBuilder` defaults that you can override:
     *
     * [`limit`](https://www.wix.com/velo/reference/wix-events-v2/policies/policiesquerybuilder/limit): `50`
     * [`descending`](https://www.wix.com/velo/reference/wix-events-v2/policies/policiesquerybuilder/descending): `_createdDate`
     *
     * The functions that are chained to `queryPolicies()` are applied in the order they are called. For example, if you sort on the `_createdDate` property in ascending order and then on the id property in descending order, the results are sorted by the created date and then, if there are multiple results with the same date, the items are sorted by the id.
     *
     * The table below shows which `PoliciesQueryBuilder` functions are supported for `queryPoliciesGuests()`. You can only use one filter function for each property. If a property is used in more than one filter, only the first filter will work.
     */
    (): PoliciesQueryBuilder;
}
declare function reorderEventPolicies$1(httpClient: HttpClient): ReorderEventPoliciesSignature;
interface ReorderEventPoliciesSignature {
    /**
     * Changes policy order in an event dashboard and agreement checkbox on the checkout form.
     * For example, if we have 3 policies in the list, after using this function the 3rd policy will become the 1st, and other policies will move by 1 position. By default, the policies are arranged by the created date in descending order.
     *
     * >  **Note**: it is possible to use both `beforePolicyId` and `afterPolicyId` at the same time but only the last one defined will be executed.
     *
     * <!--
     * >  Note: This function is restricted and only runs if you elevate permissions using the [wix-auth.elevate()](https://www.wix.com/velo/reference/wix-auth/elevate) function.
     * -->
     *
     * The `reorderEventPolicies()` function returns a Promise that resolves to the newly-reordered policy.
     * @param - Event policy ID.
     * @param - Event ID.
     * @param - Options for Reorder Event Policies function.
     */
    (policyId: string, eventId: string, options?: ReorderEventPoliciesOptions): Promise<NonNullablePaths<ReorderEventPoliciesResponse, {
        [P in PolicyNonNullablePaths]: `policies.${number}.${P}`;
    }[PolicyNonNullablePaths]> & {
        __applicationErrorsType?: ReorderEventPoliciesApplicationErrors;
    }>;
}
declare function getPolicy$1(httpClient: HttpClient): GetPolicySignature;
interface GetPolicySignature {
    /**
     * Retrieves a policy by ID.
     *
     *
     * The `getPolicy()` function returns a Promise that resolves to a policy whose ID matches the given ID.
     * @param - Policy ID.
     * @returns The requested policy.
     */
    (policyId: string): Promise<NonNullablePaths<Policy, PolicyNonNullablePaths>>;
}
declare const onPolicyCreated$1: EventDefinition<PolicyCreatedEnvelope, "wix.events.v2.policy_created">;
declare const onPolicyDeleted$1: EventDefinition<PolicyDeletedEnvelope, "wix.events.v2.policy_deleted">;
declare const onPolicyUpdated$1: EventDefinition<PolicyUpdatedEnvelope, "wix.events.v2.policy_updated">;

declare const createPolicy: MaybeContext<BuildRESTFunction<typeof createPolicy$1> & typeof createPolicy$1>;
declare const updatePolicy: MaybeContext<BuildRESTFunction<typeof updatePolicy$1> & typeof updatePolicy$1>;
declare const deletePolicy: MaybeContext<BuildRESTFunction<typeof deletePolicy$1> & typeof deletePolicy$1>;
declare const queryPolicies: MaybeContext<BuildRESTFunction<typeof queryPolicies$1> & typeof queryPolicies$1>;
declare const reorderEventPolicies: MaybeContext<BuildRESTFunction<typeof reorderEventPolicies$1> & typeof reorderEventPolicies$1>;
declare const getPolicy: MaybeContext<BuildRESTFunction<typeof getPolicy$1> & typeof getPolicy$1>;
/**
 * Triggered when a policy is created.
 */
declare const onPolicyCreated: BuildEventDefinition<typeof onPolicyCreated$1>;
/**
 * Triggered when a policy is deleted.
 */
declare const onPolicyDeleted: BuildEventDefinition<typeof onPolicyDeleted$1>;
/**
 * Triggered when a policy is updated.
 */
declare const onPolicyUpdated: BuildEventDefinition<typeof onPolicyUpdated$1>;

export { PoliciesQueryBuilder, Policy, PolicyCreatedEnvelope, PolicyDeletedEnvelope, PolicyUpdatedEnvelope, ReorderEventPoliciesOptions, ReorderEventPoliciesResponse, UpdatePolicy, createPolicy, deletePolicy, getPolicy, onPolicyCreated, onPolicyDeleted, onPolicyUpdated, queryPolicies, reorderEventPolicies, updatePolicy };
